# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/audio/frame_aac.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%make87_messages/audio/frame_aac.proto\x12\x15make87_messages.audio\x1a!make87_messages/core/header.proto\"\xb6\x01\n\x08\x46rameAac\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03pts\x18\x03 \x01(\x03\x12;\n\ttime_base\x18\x04 \x01(\x0b\x32(.make87_messages.audio.FrameAac.Fraction\x1a$\n\x08\x46raction\x12\x0b\n\x03num\x18\x01 \x01(\r\x12\x0b\n\x03\x64\x65n\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.audio.frame_aac_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FRAMEAAC']._serialized_start=100
  _globals['_FRAMEAAC']._serialized_end=282
  _globals['_FRAMEAAC_FRACTION']._serialized_start=246
  _globals['_FRAMEAAC_FRACTION']._serialized_end=282
# @@protoc_insertion_point(module_scope)
