# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/spatial/pose/pose_2d.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.spatial.translation import translation_2d_pb2 as make87__messages_dot_spatial_dot_translation_dot_translation__2d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*make87_messages/spatial/pose/pose_2d.proto\x12\x1cmake87_messages.spatial.pose\x1a!make87_messages/core/header.proto\x1a\x38make87_messages/spatial/translation/translation_2d.proto\"\x91\x01\n\x06Pose2D\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12G\n\x0btranslation\x18\x02 \x01(\x0b\x32\x32.make87_messages.spatial.translation.Translation2D\x12\x10\n\x08rotation\x18\x03 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.spatial.pose.pose_2d_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_POSE2D']._serialized_start=170
  _globals['_POSE2D']._serialized_end=315
# @@protoc_insertion_point(module_scope)
