# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/audio/any.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.audio import frame_pcm_s16le_pb2 as make87__messages_dot_audio_dot_frame__pcm__s16le__pb2
from make87_messages.audio import frame_aac_pb2 as make87__messages_dot_audio_dot_frame__aac__pb2
from make87_messages.audio import frame_opus_pb2 as make87__messages_dot_audio_dot_frame__opus__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmake87_messages/audio/any.proto\x12\x15make87_messages.audio\x1a!make87_messages/core/header.proto\x1a+make87_messages/audio/frame_pcm_s16le.proto\x1a%make87_messages/audio/frame_aac.proto\x1a&make87_messages/audio/frame_opus.proto\"\xdd\x01\n\x08\x46rameAny\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x39\n\tpcm_s16le\x18\x02 \x01(\x0b\x32$.make87_messages.audio.FramePcmS16leH\x00\x12.\n\x03\x61\x61\x63\x18\x03 \x01(\x0b\x32\x1f.make87_messages.audio.FrameAacH\x00\x12\x30\n\x04opus\x18\x04 \x01(\x0b\x32 .make87_messages.audio.FrameOpusH\x00\x42\x06\n\x04\x64\x61tab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.audio.any_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FRAMEANY']._serialized_start=218
  _globals['_FRAMEANY']._serialized_end=439
# @@protoc_insertion_point(module_scope)
