# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/transport/auth.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$make87_messages/transport/auth.proto\x12\x1emake87_messages.transport.auth\x1a!make87_messages/core/header.proto\"]\n\tBasicAuth\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\xdd\x01\n\nDigestAuth\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\r\n\x05realm\x18\x04 \x01(\t\x12\r\n\x05nonce\x18\x05 \x01(\t\x12\x0e\n\x06opaque\x18\x06 \x01(\t\x12\x42\n\talgorithm\x18\x07 \x01(\x0e\x32/.make87_messages.transport.auth.DigestAlgorithm\x12\x0b\n\x03qop\x18\x08 \x01(\t\"J\n\x0b\x42\x65\x61rerToken\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05token\x18\x02 \x01(\t*\x7f\n\x0f\x44igestAlgorithm\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x07\n\x03MD5\x10\x01\x12\x0c\n\x08MD5_SESS\x10\x02\x12\x0b\n\x07SHA_256\x10\x03\x12\x10\n\x0cSHA_256_SESS\x10\x04\x12\x0f\n\x0bSHA_512_256\x10\x05\x12\x14\n\x10SHA_512_256_SESS\x10\x06\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.transport.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DIGESTALGORITHM']._serialized_start=502
  _globals['_DIGESTALGORITHM']._serialized_end=629
  _globals['_BASICAUTH']._serialized_start=107
  _globals['_BASICAUTH']._serialized_end=200
  _globals['_DIGESTAUTH']._serialized_start=203
  _globals['_DIGESTAUTH']._serialized_end=424
  _globals['_BEARERTOKEN']._serialized_start=426
  _globals['_BEARERTOKEN']._serialized_end=500
# @@protoc_insertion_point(module_scope)
