# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/video/any.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.video import frame_h264_pb2 as make87__messages_dot_video_dot_frame__h264__pb2
from make87_messages.video import frame_h265_pb2 as make87__messages_dot_video_dot_frame__h265__pb2
from make87_messages.video import frame_av1_pb2 as make87__messages_dot_video_dot_frame__av1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmake87_messages/video/any.proto\x12\x15make87_messages.video\x1a!make87_messages/core/header.proto\x1a&make87_messages/video/frame_h264.proto\x1a&make87_messages/video/frame_h265.proto\x1a%make87_messages/video/frame_av1.proto\"\xd4\x01\n\x08\x46rameAny\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x30\n\x04h264\x18\x02 \x01(\x0b\x32 .make87_messages.video.FrameH264H\x00\x12\x30\n\x04h265\x18\x03 \x01(\x0b\x32 .make87_messages.video.FrameH265H\x00\x12.\n\x03\x61v1\x18\x04 \x01(\x0b\x32\x1f.make87_messages.video.FrameAV1H\x00\x42\x06\n\x04\x64\x61ta\"\xec\x01\n\x0e\x46rameMpegTsAny\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x36\n\x04h264\x18\x02 \x01(\x0b\x32&.make87_messages.video.FrameMpegTsH264H\x00\x12\x36\n\x04h265\x18\x03 \x01(\x0b\x32&.make87_messages.video.FrameMpegTsH265H\x00\x12\x34\n\x03\x61v1\x18\x04 \x01(\x0b\x32%.make87_messages.video.FrameMpegTsAV1H\x00\x42\x06\n\x04\x64\x61tab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.video.any_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FRAMEANY']._serialized_start=213
  _globals['_FRAMEANY']._serialized_end=425
  _globals['_FRAMEMPEGTSANY']._serialized_start=428
  _globals['_FRAMEMPEGTSANY']._serialized_end=664
# @@protoc_insertion_point(module_scope)
