# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/image/uncompressed/any.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.image.uncompressed import image_rgb888_pb2 as make87__messages_dot_image_dot_uncompressed_dot_image__rgb888__pb2
from make87_messages.image.uncompressed import image_rgba8888_pb2 as make87__messages_dot_image_dot_uncompressed_dot_image__rgba8888__pb2
from make87_messages.image.uncompressed import image_yuv420_pb2 as make87__messages_dot_image_dot_uncompressed_dot_image__yuv420__pb2
from make87_messages.image.uncompressed import image_yuv422_pb2 as make87__messages_dot_image_dot_uncompressed_dot_image__yuv422__pb2
from make87_messages.image.uncompressed import image_yuv444_pb2 as make87__messages_dot_image_dot_uncompressed_dot_image__yuv444__pb2
from make87_messages.image.uncompressed import image_nv12_pb2 as make87__messages_dot_image_dot_uncompressed_dot_image__nv12__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,make87_messages/image/uncompressed/any.proto\x12\"make87_messages.image.uncompressed\x1a!make87_messages/core/header.proto\x1a\x35make87_messages/image/uncompressed/image_rgb888.proto\x1a\x37make87_messages/image/uncompressed/image_rgba8888.proto\x1a\x35make87_messages/image/uncompressed/image_yuv420.proto\x1a\x35make87_messages/image/uncompressed/image_yuv422.proto\x1a\x35make87_messages/image/uncompressed/image_yuv444.proto\x1a\x33make87_messages/image/uncompressed/image_nv12.proto\"\xce\x01\n\x0bImageRGBAny\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x41\n\x06rgb888\x18\x02 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageRGB888H\x00\x12\x45\n\x08rgba8888\x18\x03 \x01(\x0b\x32\x31.make87_messages.image.uncompressed.ImageRGBA8888H\x00\x42\x07\n\x05image\"\xcc\x02\n\x0bImageYUVAny\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x41\n\x06yuv420\x18\x02 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageYUV420H\x00\x12\x41\n\x06yuv422\x18\x03 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageYUV422H\x00\x12\x41\n\x06yuv444\x18\x04 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageYUV444H\x00\x12=\n\x04nv12\x18\x05 \x01(\x0b\x32-.make87_messages.image.uncompressed.ImageNV12H\x00\x42\x07\n\x05image\"\xd6\x03\n\x0bImageRawAny\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x41\n\x06rgb888\x18\x02 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageRGB888H\x00\x12\x45\n\x08rgba8888\x18\x03 \x01(\x0b\x32\x31.make87_messages.image.uncompressed.ImageRGBA8888H\x00\x12\x41\n\x06yuv420\x18\x04 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageYUV420H\x00\x12\x41\n\x06yuv422\x18\x05 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageYUV422H\x00\x12\x41\n\x06yuv444\x18\x06 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageYUV444H\x00\x12=\n\x04nv12\x18\x07 \x01(\x0b\x32-.make87_messages.image.uncompressed.ImageNV12H\x00\x42\x07\n\x05imageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.image.uncompressed.any_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IMAGERGBANY']._serialized_start=450
  _globals['_IMAGERGBANY']._serialized_end=656
  _globals['_IMAGEYUVANY']._serialized_start=659
  _globals['_IMAGEYUVANY']._serialized_end=991
  _globals['_IMAGERAWANY']._serialized_start=994
  _globals['_IMAGERAWANY']._serialized_end=1464
# @@protoc_insertion_point(module_scope)
