# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/transport/http.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.transport import endpoint_pb2 as make87__messages_dot_transport_dot_endpoint__pb2
from make87_messages.transport import auth_pb2 as make87__messages_dot_transport_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$make87_messages/transport/http.proto\x12\x1emake87_messages.transport.http\x1a!make87_messages/core/header.proto\x1a(make87_messages/transport/endpoint.proto\x1a$make87_messages/transport/auth.proto\"\x91\x04\n\x0bHTTPRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12>\n\x08\x65ndpoint\x18\x02 \x01(\x0b\x32,.make87_messages.transport.endpoint.Endpoint\x12:\n\x06method\x18\x03 \x01(\x0e\x32*.make87_messages.transport.http.HTTPMethod\x12I\n\x07headers\x18\x04 \x03(\x0b\x32\x38.make87_messages.transport.http.HTTPRequest.HeadersEntry\x12\x0c\n\x04\x62ody\x18\x05 \x01(\x0c\x12?\n\nbasic_auth\x18\x06 \x01(\x0b\x32).make87_messages.transport.auth.BasicAuthH\x00\x12\x41\n\x0b\x64igest_auth\x18\x07 \x01(\x0b\x32*.make87_messages.transport.auth.DigestAuthH\x00\x12\x43\n\x0c\x62\x65\x61rer_token\x18\x08 \x01(\x0b\x32+.make87_messages.transport.auth.BearerTokenH\x00\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04\x61uth*g\n\nHTTPMethod\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x07\n\x03GET\x10\x01\x12\x08\n\x04POST\x10\x02\x12\x07\n\x03PUT\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x12\x08\n\x04HEAD\x10\x05\x12\x0b\n\x07OPTIONS\x10\x06\x12\t\n\x05PATCH\x10\x07\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.transport.http_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HTTPREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPMETHOD']._serialized_start=719
  _globals['_HTTPMETHOD']._serialized_end=822
  _globals['_HTTPREQUEST']._serialized_start=188
  _globals['_HTTPREQUEST']._serialized_end=717
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_start=663
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_end=709
# @@protoc_insertion_point(module_scope)
