# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/detection/box/box_2d.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.geometry.box import box_2d_pb2 as make87__messages_dot_geometry_dot_box_dot_box__2d__pb2
from make87_messages.geometry.box import box_2d_aligned_pb2 as make87__messages_dot_geometry_dot_box_dot_box__2d__aligned__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*make87_messages/detection/box/box_2d.proto\x12\x1dmake87_messages.detection.box\x1a!make87_messages/core/header.proto\x1a)make87_messages/geometry/box/box_2d.proto\x1a\x31make87_messages/geometry/box/box_2d_aligned.proto\"\x92\x01\n\x05\x42ox2D\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x35\n\x08geometry\x18\x02 \x01(\x0b\x32#.make87_messages.geometry.box.Box2D\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\x10\n\x08\x63lass_id\x18\x04 \x01(\x05\"\xa8\x01\n\x10\x42ox2DAxisAligned\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12@\n\x08geometry\x18\x02 \x01(\x0b\x32..make87_messages.geometry.box.Box2DAxisAligned\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\x10\n\x08\x63lass_id\x18\x04 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.detection.box.box_2d_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BOX2D']._serialized_start=207
  _globals['_BOX2D']._serialized_end=353
  _globals['_BOX2DAXISALIGNED']._serialized_start=356
  _globals['_BOX2DAXISALIGNED']._serialized_end=524
# @@protoc_insertion_point(module_scope)
