# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/transport/endpoint.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(make87_messages/transport/endpoint.proto\x12\"make87_messages.transport.endpoint\x1a!make87_messages/core/header.proto\"\xfd\x01\n\x08\x45ndpoint\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\x0c\n\x04host\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\r\x12\x0c\n\x04path\x18\x05 \x01(\t\x12S\n\x0cquery_params\x18\x06 \x03(\x0b\x32=.make87_messages.transport.endpoint.Endpoint.QueryParamsEntry\x1a\x32\n\x10QueryParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.transport.endpoint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ENDPOINT_QUERYPARAMSENTRY']._loaded_options = None
  _globals['_ENDPOINT_QUERYPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_ENDPOINT']._serialized_start=116
  _globals['_ENDPOINT']._serialized_end=369
  _globals['_ENDPOINT_QUERYPARAMSENTRY']._serialized_start=319
  _globals['_ENDPOINT_QUERYPARAMSENTRY']._serialized_end=369
# @@protoc_insertion_point(module_scope)
