# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/transport/rtsp.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.transport import endpoint_pb2 as make87__messages_dot_transport_dot_endpoint__pb2
from make87_messages.transport import auth_pb2 as make87__messages_dot_transport_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$make87_messages/transport/rtsp.proto\x12\x1emake87_messages.transport.rtsp\x1a!make87_messages/core/header.proto\x1a(make87_messages/transport/endpoint.proto\x1a$make87_messages/transport/auth.proto\"\xbe\x03\n\x0bRTSPRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12>\n\x08\x65ndpoint\x18\x02 \x01(\x0b\x32,.make87_messages.transport.endpoint.Endpoint\x12:\n\x06method\x18\x03 \x01(\x0e\x32*.make87_messages.transport.rtsp.RTSPMethod\x12I\n\x07headers\x18\x04 \x03(\x0b\x32\x38.make87_messages.transport.rtsp.RTSPRequest.HeadersEntry\x12?\n\nbasic_auth\x18\x05 \x01(\x0b\x32).make87_messages.transport.auth.BasicAuthH\x00\x12\x41\n\x0b\x64igest_auth\x18\x06 \x01(\x0b\x32*.make87_messages.transport.auth.DigestAuthH\x00\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04\x61uth*\x98\x01\n\nRTSPMethod\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07OPTIONS\x10\x01\x12\x0c\n\x08\x44\x45SCRIBE\x10\x02\x12\t\n\x05SETUP\x10\x03\x12\x08\n\x04PLAY\x10\x04\x12\t\n\x05PAUSE\x10\x05\x12\x0c\n\x08TEARDOWN\x10\x06\x12\x11\n\rGET_PARAMETER\x10\x07\x12\x11\n\rSET_PARAMETER\x10\x08\x12\n\n\x06RECORD\x10\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.transport.rtsp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RTSPREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_RTSPREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_RTSPMETHOD']._serialized_start=637
  _globals['_RTSPMETHOD']._serialized_end=789
  _globals['_RTSPREQUEST']._serialized_start=188
  _globals['_RTSPREQUEST']._serialized_end=634
  _globals['_RTSPREQUEST_HEADERSENTRY']._serialized_start=580
  _globals['_RTSPREQUEST_HEADERSENTRY']._serialized_end=626
# @@protoc_insertion_point(module_scope)
